#!/usr/bin/perl -I/usr/sausalito/perl
# $Id: service_quota.pl,v 1.4 2001/10/26 00:12:43 will Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
#
# manages the per-site anonymous FTP ServiceQuota objects for site-level
# disk usage stats

use CCE;
use Data::Dumper;

my $DEBUG = 0;
$DEBUG && open STDERR, ">/tmp/service_quota";
$DEBUG && warn `date`."$0\n";

my $cce = new CCE;
$cce->connectfd();

my $err; # Global error message/return state

# Just the facts
my $oid = $cce->event_oid();
my $obj = $cce->event_object();
my $obj_new = $cce->event_new();
my $obj_old = $cce->event_old();

# Find matching ServiceQuota objects
my $sitegroup = $obj_old->{anonymousOwner};
$sitegroup ||= $obj->{anonymousOwner};
my @oids = $cce->find('ServiceQuota', {
	'site' => $sitegroup,
	'label' => '[[base-ftp.anonServiceQuota]]',
	}); 

if($cce->event_is_destroy() || !$obj->{anonymous})
{
	# destroy the associated ServiceQuota object
	foreach my $i (@oids)
	{
		my ($ret, @info) = $cce->destroy($i);
		$err .= '[[base-ftp.couldNotClearFtpQuotaMon]]' 
			unless ($ret);
	}
} 
elsif ($obj_new->{anonymous})
{
	# create a ServiceQuota object
	$owner = $obj->{anonymousOwner};
	$owner =~ tr/[a-z]/[A-Z]/;

	my($ret) = $cce->create('ServiceQuota', { 
		'label' => '[[base-ftp.anonServiceQuota]]',
		'site' => $obj->{anonymousOwner},
		'account' => $owner,
		'isgroup' => 0,
		'quota' => $obj->{quota},
		'used' => 0,
		});
		
	$err .= '[[base-ftp.couldNotSetFtpQuotaMon]]' 
		unless ($ret);
}
elsif ($obj_new->{quota})
{
	foreach my $i (@oids)
	{
		my ($ret) = $cce->set($i, '', {
			'quota' => $obj_new->{quota}
			});
		$err .= '[[base-ftp.couldNotUpdateFtpQuotaMon]]' 
			unless ($ret);
	}
} 

if($err)
{
	$cce->bye('FAIL', $err);
	exit 1;
}
else
{
	$cce->bye('SUCCESS');
	exit 0;
}

