#!/usr/bin/perl -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/ftp
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
# $Id: vsite_suspend.pl,v 1.6 2002/04/05 00:12:39 pbaltz Exp $
# 
# Bring down anonymous ftp and also ftp for the vsite's ip address, if
# it is the only site using the ip, when a Vsite is suspended.

use CCE;

my $cce = new CCE('Domain' => 'base-ftp');
$cce->connectfd();

my $vsite = $cce->event_object();
my ($ftp_site) = $cce->find('FtpSite', 
                    { 'ipaddr' => $vsite->{ipaddr} });
my ($ok, $anon_ftp) = $cce->get($cce->event_oid(), 'AnonFtp');

# get current ftp settings
($ok, my $ftp_settings) = $cce->get($ftp_site);

my $new_settings = {};

# disable ftp on suspend
if ($vsite->{suspend})
{
    # check if anonymous ftp needs to be disabled
    if ($anon_ftp->{enabled})
    {
        $new_settings->{anonymous} = 0;
    }

    ($ok) = $cce->set($ftp_site, '', $new_settings);
    if (not $ok)
    {
        $cce->bye('FAIL', 'cantSuspendFtp');
        exit(0);
    }

}
else # must be unsuspending a site
{
    # figure out what to do with anonymous ftp
    if ($anon_ftp->{enabled})
    {
        # make sure someone else hasn't taken over
        if ($ftp_settings->{anonymous} &&
            ($ftp_settings->{anonymousOwner} ne $vsite->{name}))
        {
            # disable anonymous for this site and issue a warning
            $cce->set($cce->event_oid(), 'AnonFtp', { 'enabled' => 0 });
            $cce->info('unsuspendAnonFtpInUse', { 'ipaddr' => $vsite->{ipaddr} });
        }
        else # reclaim anonymous ftp
        {
            $new_settings->{anonymous} = 1;
            $new_settings->{anonymousOwner} = $vsite->{name};
            $new_settings->{maxConnections} = $anon_ftp->{maxConnections};
            $new_settings->{quota} = $anon_ftp->{quota};
        }
    }

    # restore settings
    ($ok) = $cce->set($ftp_site, '', $new_settings);

    if (not $ok)
    {
        $cce->bye('FAIL', 'cantUnsuspendFtp');
        exit(0);
    }
}

$cce->bye('SUCCESS');
exit(0);

